@@ -1,15 +1,20 @@
 /*
+ *
  * This file is part of Packet Sender
  *
  * Licensed GPL v2
- * http://PacketSender.com/
+ * https://PacketSender.com/
  *
  * Copyright NagleCode, LLC
  *
  */
-#include <QtWidgets/QApplication>
+
+#include "globals.h"
+#ifndef CONSOLE_BUILD
+    #include <QtWidgets/QApplication>
+    #include <QDesktopServices>
+#endif
 #include <QDir>
-#include <QDesktopServices>
 #include <QCommandLineParser>
 #include <QHostInfo>
 #include <QSslError>
@@ -18,10 +23,13 @@
 #include <QDeadlineTimer>
 #include <QProcess>
 #include <QStandardPaths>
+#include <QSettings>
 
 #include "mainpacketreceiver.h"
 
-#include "mainwindow.h"
+#ifndef CONSOLE_BUILD
+    #include "mainwindow.h"
+#endif
 #define DEBUGMODE 0
 
 
@@ -144,7 +152,12 @@ int main(int argc, char *argv[])
     srand(time(NULL));
 #endif
 
-    if ((argc > 1) && !gatekeeper) {
+    if (((argc > 1) && (!gatekeeper))
+
+#ifdef CONSOLE_BUILD
+    || true
+#endif
+    ) {
         QCoreApplication a(argc, argv);
         args = a.arguments();
 
@@ -174,19 +187,20 @@ int main(int argc, char *argv[])
         QCoreApplication::setApplicationVersion(versionBuilder);
 
         QCommandLineParser parser;
-        parser.setApplicationDescription("Packet Sender is a Network UDP/TCP/SSL Test Utility by NagleCode\nSee https://PacketSender.com/ for more information.");
+        parser.setApplicationDescription("Packet Sender is a Network UDP/TCP/SSL/HTTP Test Utility by NagleCode\nSee https://PacketSender.com/ for more information.");
         parser.addHelpOption();
         parser.addVersionOption();
 
+
         // A boolean option with a single name (-p)
         QCommandLineOption quietOption(QStringList() << "q" << "quiet", "Quiet mode. Only output received data.");
         parser.addOption(quietOption);
 
 
-        QCommandLineOption hexOption(QStringList() << "x" << "hex", "Parse data-to-send as hex (default).");
+        QCommandLineOption hexOption(QStringList() << "x" << "hex", "Parse data-to-send as hex (default for TCP/UDP/SSL).");
         parser.addOption(hexOption);
 
-        QCommandLineOption asciiOption(QStringList() << "a" << "ascii", "Parse data-to-send as mixed-ascii (like the GUI).");
+        QCommandLineOption asciiOption(QStringList() << "a" << "ascii", "Parse data-to-send as mixed-ascii (default for http and GUI).");
         parser.addOption(asciiOption);
 
         QCommandLineOption pureAsciiOption(QStringList() << "A" << "ASCII", "Parse data-to-send as pure ascii (no \\xx translation).");
@@ -235,8 +249,8 @@ int main(int argc, char *argv[])
         QCommandLineOption udpOption(QStringList() << "u" << "udp", "Send UDP.");
         parser.addOption(udpOption);
 
-        // A boolean option with single name
-        QCommandLineOption httpOption(QStringList() << "http", "Send HTTP.");
+        // A single option with a value
+        QCommandLineOption httpOption(QStringList() << "http", "Send HTTP. Allowed values are GET (default) and POST", "http");
         parser.addOption(httpOption);
 
         // An option with a value
@@ -261,9 +275,14 @@ int main(int argc, char *argv[])
 
         parser.addPositionalArgument("address", "Destination address/URL. Optional for saved packet.");
         parser.addPositionalArgument("port", "Destination port/POST data. Optional for saved packet.");
-        parser.addPositionalArgument("data", "Data to send. Optional for saved packet or HTTP.");
+        parser.addPositionalArgument("data", "Data to send. Optional for saved packet.");
 
 
+        if (argc < 2) {
+            parser.showHelp();
+            return 0;
+        }
+
         // Process the actual command line arguments given by the user
         parser.process(a);
 
@@ -298,7 +317,7 @@ int main(int argc, char *argv[])
         qint64 usdelay = parser.value(usdelayOption).toULongLong();
         if(intense) {
             if (!okrate && !okbps) {
-                OUTIF() << "Warning: Invalide rate and/or bps. Intense traffic will free-run.";
+                OUTIF() << "Warning: Invalid rate and/or bps. Intense traffic will free-run.";
                 bps = 0;
                 rate = 0;
             }
@@ -308,6 +327,10 @@ int main(int argc, char *argv[])
 
         QString name = parser.value(nameOption);
 
+        QString httpMethod = parser.value(httpOption).trimmed().toUpper();
+
+
+
         QString filePath = parser.value(fileOption);
 
 
@@ -316,6 +339,7 @@ int main(int argc, char *argv[])
         unsigned int port = 0;
 
         int argssize = args.size();
+        QDEBUGVAR(argssize);
         QString data, dataString;
         data.clear();
         dataString.clear();
@@ -323,12 +347,37 @@ int main(int argc, char *argv[])
             address = args[0];
         }
         if(http) {
-            if (argssize >= 2) {
-                data = (args[1]);
+            if(parser.isSet(httpOption)) {
+                if(httpMethod != "GET" && httpMethod != "POST") {
+                    OUTIF() << "Error: supported HTTP methods are GET and POST. Specified: " << httpMethod;
+                    filePath.clear();
+                    OUTPUT();
+                    return -1;
+                }
+
+                if(name.isEmpty()) {
+                    if(address.isEmpty()) {
+                        OUTIF() << "Error: URL is required after HTTP method is no name is supplied.";
+                        filePath.clear();
+                        OUTPUT();
+                        return -1;
+                    }
+                }
+
+                if(httpMethod == "POST") {
+                    if(argssize < 2) {
+                        OUTIF() << "Error: data is required after specifying POST.";
+                        filePath.clear();
+                        OUTPUT();
+                        return -1;
+                    } else {
+                        data = args[1];
+                    }
+                }
+
             }
 
         } else {
-
             if (argssize >= 2) {
                 port = args[1].toUInt();
             }
@@ -437,7 +486,11 @@ int main(int argc, char *argv[])
 
         //set default choices
         if (!hex && !ascii && !mixedascii) {
-            hex = true;
+            if(http) {
+                mixedascii = true;
+            } else {
+                hex = true;
+            }
         }
 
         if (!tcp && !udp && !ssl && !http) {
@@ -455,22 +508,33 @@ int main(int argc, char *argv[])
             http = false;
         }
 
+        QSettings settings(SETTINGSFILE, QSettings::IniFormat);
+        bool translateMacroSend = settings.value("translateMacroSendCheck", true).toBool();
+
 
         //Create the packet to send.
         if (!name.isEmpty()) {
             sendPacket = Packet::fetchFromDB(name);
+
+            if(translateMacroSend && (!intense)) {
+                QString data = Packet::macroSwap(sendPacket.asciiString());
+                sendPacket.hexString = Packet::ASCIITohex(data);
+            }
+
+
             if (sendPacket.name.isEmpty()) {
                 OUTIF() << "Error: Saved packet \"" << name << "\" not found.";
                 OUTPUT();
                 return -1;
             } else {
+                QDEBUGVAR(sendPacket.name);
 
                 ssl = sendPacket.isSSL();
                 tcp = sendPacket.isTCP();
                 udp = sendPacket.isUDP();
                 http = sendPacket.isHTTP() || sendPacket.isHTTPS();
 
-                if (data.isEmpty()) {
+                if (data.isEmpty() && (!http)) {
                     data  = sendPacket.hexString;
                     hex = true;
                     ascii = false;
@@ -562,6 +626,8 @@ int main(int argc, char *argv[])
         QDEBUGVAR(stopnum);
         QDEBUGVAR(rate);
         QDEBUGVAR(usdelay);
+        QDEBUGVAR(translateMacroSend);
+
 
         //NOW LETS DO THIS!
 
@@ -574,14 +640,28 @@ int main(int argc, char *argv[])
 
 
         if (ascii) { //pure ascii
+            if((!intense)) {
+                data = Packet::macroSwap(data);
+            }
             dataString = Packet::byteArrayToHex(data.toLatin1());
         }
 
         if (hex) { //hex
             dataString = Packet::byteArrayToHex(Packet::HEXtoByteArray(data));
+
+            if((!intense)) {
+                Packet pkt;
+                pkt.hexString = dataString;
+                QString data = Packet::macroSwap(pkt.asciiString());
+                dataString = Packet::ASCIITohex(data);
+            }
+
         }
 
         if (mixedascii) { //mixed ascii
+            if((!intense)) {
+                data = Packet::macroSwap(data);
+            }
             dataString = Packet::ASCIITohex(data);
         }
 
@@ -589,17 +669,52 @@ int main(int argc, char *argv[])
             OUTIF() << "Warning: No data to send. Is your formatting correct?";
         }
 
-        if(http) {
-            sendPacket.requestPath = Packet::getRequestFromURL(address);
-            sendPacket.tcpOrUdp = Packet::getMethodFromURL(address);
-            if(dataString.size() > 0) {
+
+        // HTTP section
+        // Test packet 1:  .\packetsender.com --name "HTTPS POST Params"
+        // Test packet 2: .\packetsender.com --http GET "https://httpbin.org/get"
+        // Test packet 3: .\packetsender.com --http POST "https://httpbin.org/post" "{""hello"":1}"
+
+        if(http) {            
+            if ((!address.isEmpty()) && address.contains("://")) {
+                sendPacket.requestPath = Packet::getRequestFromURL(address);
+                sendPacket.tcpOrUdp = Packet::getMethodFromURL(address);
+                sendPacket.port = Packet::getPortFromURL(address);
+                sendPacket.toIP = Packet::getHostFromURL(address);
+            }
+
+            if(httpMethod.contains("POST")) {
                 sendPacket.tcpOrUdp.replace("Get", "Post");
-                sendPacket.hexString = dataString;
             }
 
-            sendPacket.port = Packet::getPortFromURL(address);
-            sendPacket.toIP = Packet::getHostFromURL(address);
             sendPacket.persistent = false;
+
+            if (!dataString.isEmpty()) {
+                sendPacket.hexString = dataString;
+
+            }
+
+
+            QString url = "";
+            QString portUrl = "";
+            QString portUrlS = ":" + QString::number(sendPacket.port);
+
+            if(sendPacket.isHTTPS()) {
+                url = "https://";
+                if(sendPacket.port != 443) {
+                    portUrl = portUrlS;
+                }
+            } else {
+                url = "http://";
+                if(sendPacket.port != 80) {
+                    portUrl = portUrlS;
+                }
+            }
+
+            QDEBUG() << "URL is" << sendPacket.toIP + portUrl + sendPacket.requestPath;
+
+
+            QDEBUG() << "HTTP" << sendPacket.tcpOrUdp << sendPacket.requestPath;
             MainPacketReceiver * receiver = new MainPacketReceiver(nullptr);
 
 
@@ -608,7 +723,7 @@ int main(int argc, char *argv[])
             receiver->send(sendPacket);
 
             for(int i=0; i<10; i++) {
-                QApplication::processEvents();
+                QCoreApplication::processEvents();
                 QThread::msleep(500);
                 if(receiver->finished) {
                     break;
@@ -813,6 +928,9 @@ int main(int argc, char *argv[])
             OUTIF() << "UDP (" << sock.localPort() << ")://" << address << ":" << port << " " << dataString;
 
             if(intense) {
+                if(translateMacroSend) {
+                    OUTIF() << "Warning: Macros can slow down intense traffic";
+                }
                 OUTIF() << "Starting Intense Traffic Generator";
                 OUTPUT();
 
@@ -895,6 +1013,9 @@ int main(int argc, char *argv[])
 #endif
 #endif
 
+
+#ifndef CONSOLE_BUILD
+
         QApplication a(argc, argv);
 
         QDEBUGVAR(args);
@@ -933,6 +1054,8 @@ int main(int argc, char *argv[])
 
         return a.exec();
 
+#endif
+
     }
 
 
@@ -943,6 +1066,10 @@ int main(int argc, char *argv[])
 
 int intenseTrafficGenerator(QTextStream &out, QUdpSocket &sock, QHostAddress addy, unsigned int port, QString hexString, double bps, double rate, qint64 stopnum, qint64 usdelay)
 {
+
+    QSettings settings(SETTINGSFILE, QSettings::IniFormat);
+    bool translateMacroSend = settings.value("translateMacroSendCheck", true).toBool();
+
     QByteArray sendData = Packet::HEXtoByteArray(hexString);
 
     if(bps > 0.1 && usdelay == 0) {
@@ -976,6 +1103,8 @@ int intenseTrafficGenerator(QTextStream &out, QUdpSocket &sock, QHostAddress add
         out << "Will stop sending after " << stopnum << " packets\n";
     }
 
+    Packet pkt;
+    pkt.hexString = Packet::byteArrayToHex(sendData);
 
 
     QElapsedTimer totalTime;
@@ -985,6 +1114,12 @@ int intenseTrafficGenerator(QTextStream &out, QUdpSocket &sock, QHostAddress add
         out << "Sending as fast as possible. Use Ctrl+C to quit.\n";
         while(1) {
 
+            if(translateMacroSend) {
+                QString data = Packet::macroSwap(pkt.asciiString());
+                pkt.hexString = Packet::ASCIITohex(data);
+                sendData = pkt.getByteArray();
+            }
+
             sock.writeDatagram(sendData, addy, port);
             STOPSENDCHECK();
 
@@ -1002,6 +1137,13 @@ int intenseTrafficGenerator(QTextStream &out, QUdpSocket &sock, QHostAddress add
             QElapsedTimer elasped;
             elasped.start();
             while(1) {
+
+                if(translateMacroSend) {
+                    QString data = Packet::macroSwap(pkt.asciiString());
+                    pkt.hexString = Packet::ASCIITohex(data);
+                    sendData = pkt.getByteArray();
+                }
+
                 sock.writeDatagram(sendData, addy, port);
                 STOPSENDCHECK();
 
