@@ -4,7 +4,7 @@
  * Licensed GPL v2
  * http://PacketSender.com/
  *
- * Copyright Dan Nagle
+ * Copyright NagleCode, LLC
  *
  */
 
@@ -22,7 +22,7 @@
 #include <QSslSocket>
 #include <QSslCipher>
 #include <QSslConfiguration>
-#include <QTemporaryFile>
+#include <QStandardPaths>
 
 
 TCPThread::TCPThread(int socketDescriptor, QObject *parent)
@@ -66,7 +66,7 @@ void TCPThread::loadSSLCerts(QSslSocket * sock, bool allowSnakeOil)
 
         // set the ca certificates from the configured path
         if (!settings.value("sslCaPath").toString().isEmpty()) {
-            sock->setCaCertificates(QSslCertificate::fromPath(settings.value("sslCaPath").toString()));
+           // sock->setCaCertificates(QSslCertificate::fromPath(settings.value("sslCaPath").toString()));
         }
 
         // set the local certificates from the configured file path
@@ -260,6 +260,10 @@ void TCPThread::persistentConnectionLoop()
                 tcpRCVPacket.fromPort =    clientConnection->peerPort();
                 if (tcpRCVPacket.hexString.size() > 0) {
                     emit packetSent(tcpRCVPacket);
+
+                    // Do I need to reply?
+                    writeResponse(clientConnection, tcpRCVPacket);
+
                 }
 
             } else {
@@ -270,10 +274,12 @@ void TCPThread::persistentConnectionLoop()
 
 
         //sendPacket.fromPort = clientConnection->localPort();
-        emit connectStatus("Sending data:" + sendPacket.asciiString());
-        QDEBUG() << "Attempting write data";
-        clientConnection->write(sendPacket.getByteArray());
-        emit packetSent(sendPacket);
+        if(sendPacket.getByteArray().size() > 0) {
+            emit connectStatus("Sending data:" + sendPacket.asciiString());
+            QDEBUG() << "Attempting write data";
+            clientConnection->write(sendPacket.getByteArray());
+            emit packetSent(sendPacket);
+        }
 
         Packet tcpPacket;
         tcpPacket.timestamp = QDateTime::currentDateTime();
@@ -323,6 +329,8 @@ void TCPThread::persistentConnectionLoop()
             emit packetSent(tcpPacket);
         }
 
+        // Do I need to reply?
+        writeResponse(clientConnection, tcpPacket);
 
 
         emit connectStatus("Reading response");
@@ -334,6 +342,10 @@ void TCPThread::persistentConnectionLoop()
 
         if (tcpPacket.hexString.size() > 0) {
             emit packetSent(tcpPacket);
+
+            // Do I need to reply?
+            writeResponse(clientConnection, tcpPacket);
+
         }
 
 
@@ -416,7 +428,13 @@ void TCPThread::run()
 
             QDEBUG() << "isEncrypted" << clientConnection->isEncrypted();
 
-            QList<QSslError> sslErrorsList  = clientConnection->sslErrors();
+            QList<QSslError> sslErrorsList  = clientConnection->
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                    sslErrors();
+#else
+                    sslHandshakeErrors();
+#endif
+
             Packet errorPacket = sendPacket;
             if (sslErrorsList.size() > 0) {
                 QSslError sError;
@@ -550,7 +568,13 @@ void TCPThread::run()
         sock.startServerEncryption();
         sock.waitForEncrypted();
 
-        QList<QSslError> sslErrorsList  = sock.sslErrors();
+        QList<QSslError> sslErrorsList  = sock
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                            .sslErrors();
+#else
+                            .sslHandshakeErrors();
+#endif
 
         Packet errorPacket;
         errorPacket.init();
@@ -608,7 +632,16 @@ void TCPThread::run()
         }
 
 
-        QDEBUG() << "Errors" << sock.sslErrors();
+        QDEBUG() << "Errors" << sock
+
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                            .sslErrors();
+#else
+                            .sslHandshakeErrors();
+#endif
+
+
 
     }
 
